/*
 ## Cypress FX3 Boot Firmware Example Source file (main.c)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2011-2012,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
*/
#include "cyu3system.h"
#include "cyfx3device.h"
#include "cyfx3utils.h"
#include "cyfx3gpio.h"
#include "defines.h"
#include "I2C.h"
#include "cyfx3i2c.h"
#include <cyu3mipicsi.h>





/****************************************************************************
 * main:
 ****************************************************************************/

int
main (void)
{
	static uint32_t gReadBuf[4]= {0xFF, 0xFF, 0xFF, 0xFF};
	static uint8_t gWriteBuf[4] = {1,2,3,4};
	static uint8_t buffer[10] = {0xFF, 0xFF, 0xFF, 0xFF,0xFF, 0xFF, 0xFF, 0xFF,0xFF, 0xFF};
    uint8_t               *wd_buf = (uint8_t *)gWriteBuf;
    uint8_t               *rd_buf = (uint8_t *)gReadBuf;
    CyFx3BootI2cConfig_t   i2cConfig;
    CyFx3BootErrorCode_t        status;
    CyFx3BootIoMatrixConfig_t   ioCfg;
    CyFx3BootGpioSimpleConfig_t gpioConf;
    CyBool_t                    value;

    /* HW and SW initialization code  */
    CyFx3BootDeviceInit (CyTrue);


    /* Enable the GPIOs for the LED and the switch. */
    ioCfg.isDQ32Bit = CyFalse;
    ioCfg.useUart   = CyFalse;
    ioCfg.useI2C    = CyFalse;
    ioCfg.useI2S    = CyFalse;
    ioCfg.useSpi    = CyFalse;
    ioCfg.gpioSimpleEn[0] = 0;
    ioCfg.gpioSimpleEn[1] = (1 << (APP_LED_GPIO - 32)) | (1 << (APP_SWITCH_GPIO - 32) | (1 << (APP_LED_GPIO2 - 32)) | (1 << (APP_LED_GPIO3 - 32)) | (1 << (APP_LED_GPIO4 - 32)));

    status = CyFx3BootDeviceConfigureIOMatrix (&ioCfg);
    if (status != CY_FX3_BOOT_SUCCESS)
    {
        return status;
    }

    /* Initialize the GPIO module. */
    CyFx3BootGpioInit ();

    /* Configure the GPIO for driving the LED. */
    gpioConf.inputEn     = CyFalse;
    gpioConf.driveLowEn  = CyTrue;
    gpioConf.driveHighEn = CyTrue;
    gpioConf.outValue    = CyFalse;
    gpioConf.intrMode    = CY_FX3_BOOT_GPIO_NO_INTR;

    //CyU3PMipicsiReset(CY_U3P_CSI_HARD_RST);
    CyU3PMipicsiSetSensorControl(CY_U3P_CSI_IO_XRES,CyTrue);
    status = CyFx3BootI2cInit ();
    if (status != CY_FX3_BOOT_SUCCESS)
        return CyFalse;


    i2cConfig.busTimeout = I2C_BUS_TIMEOUT_VALUE;
    i2cConfig.dmaTimeout = I2C_DMA_TIMEOUT_VALUE;
    i2cConfig.isDma      = CyFalse;
    i2cConfig.bitRate    = I2C_FREQUENCY_100khz;
    status = CyFx3BootI2cSetConfig (&i2cConfig);
    if (status != CY_FX3_BOOT_SUCCESS)
        return CyFalse;

    status = CyFx3BootGpioSetSimpleConfig (APP_LED_GPIO, &gpioConf);
    if (status != CY_FX3_BOOT_SUCCESS)
        return status;


    status = CyFx3BootGpioSetSimpleConfig (APP_LED_GPIO2, &gpioConf);
    if (status != CY_FX3_BOOT_SUCCESS)
        return status;


    status = CyFx3BootGpioSetSimpleConfig (APP_LED_GPIO3, &gpioConf);
    if (status != CY_FX3_BOOT_SUCCESS)
        return status;


    status = CyFx3BootGpioSetSimpleConfig (APP_LED_GPIO4, &gpioConf);
    if (status != CY_FX3_BOOT_SUCCESS)
        return status;

    /* We keep looping around and copying the state of the SWITCH GPIO onto the LED GPIO. */

   // I2c_Write(I2C_SLAVE_ADDRESS_EEPROM,0x0000,wd_buf,4);
    CyFx3BootBusyWait (50000);
  //  value = I2c_Read(I2C_SLAVE_ADDRESS_EEPROM,0x1200,rd_buf,4);
    value = I2c_Read(I2C_SLAVE_ADDRESS_TI_DES,0x0000,rd_buf,FW_HEADER_SIZE);

	if (value == CyTrue)
	{
		CyFx3BootGpioSetValue(APP_LED_GPIO4, CyTrue);		//	0 1 1 0
		CyFx3BootGpioSetValue(APP_LED_GPIO2, CyFalse);
		CyFx3BootGpioSetValue(APP_LED_GPIO3, CyFalse);
		CyFx3BootGpioSetValue(APP_LED_GPIO, CyTrue);
	   // CyU3PDebugPrint (1,"I2C access - dev: 0x%x, address: ");

	} else
	{
		CyFx3BootGpioSetValue(APP_LED_GPIO, CyFalse);			//	1 0 0 1
		CyFx3BootGpioSetValue(APP_LED_GPIO3, CyTrue);
		CyFx3BootGpioSetValue(APP_LED_GPIO2, CyTrue);
		CyFx3BootGpioSetValue(APP_LED_GPIO4, CyFalse);
	}

    return 0;
}


/*[]*/

